netapp_ontap.models.iscsi_session_initiator API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.iscsi_session_initiator`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IscsiSessionInitiatorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IscsiSessionInitiator object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `alias: str GET`

    The initiator alias.

    Example: initiator_alias1

  `comment: str GET`

    A comment available for use by the administrator. This is modifiable from the initiator REST endpoint directly. See `PATCH /protocols/san/igroups/{igroup.uuid}/initiators/{name}`.

    Example: This is an iSCSI initiator for host 5

  `name: str GET`

    The world wide unique name of the initiator.

    Example: iqn.1992-01.example.com:string